/**
 * @file        ADSO-9534
 * @description Set non-default UoM to default
 * @author      Chan Clarence (ccn7@3ds.com)
 * @copyright   Dassault Systèmes
 */
import { qCustomMatcher } from '../../e2elib/lib/src/main/qmatchers.const';
import { AppMP, Demo, Scenario } from '../../libmp/appmp';
import { DataFoodBaseUoM } from '../../libmp/data/data.unitofmeasure';
import { ListUnitsOfMeasureContextMenuItem } from '../../libmp/forms/form.unitsofmeasure';

describe('ADSO-9534 - Set non-default UoM to default', () => {
  const appMP = AppMP.getInstance();
  const listUoM = appMP.viewUnitsOfMeasure.formUnitsOfMeasure.listUnitsOfMeasure;
  const uomMT = DataFoodBaseUoM.MT;
  const uomCase = DataFoodBaseUoM.Case;

  beforeAll(async () => {
    jasmine.addMatchers(qCustomMatcher);
    await appMP.login();
  });

  afterAll(async () => {
    await appMP.viewUnitsOfMeasure.reset();
    await appMP.cleanupAndLogout();
  });

  afterEach(async () => {
    await appMP.checkToastMessage();
  });

  it(`Step 1 - ${AppMP.getDemoDataPath(Demo.Food, Scenario.Base)}`, async () => {
    await appMP.createDemoDataset(Demo.Food, Scenario.Base, false);
  });

  it(`Step 2 - Open view ${appMP.viewUnitsOfMeasure.viewPath}. Verify first row Name = ${uomMT} and is default UoM (Name cell is bold).`, async () => {
    await appMP.viewUnitsOfMeasure.switchTo();

    await listUoM.verifyFirstRowDefaultUoM(uomMT);
  });

  it(`Step 3 - Select Case UoM and right click select menu "Set as default". Verify ${uomCase} is now moved to first row and is default UoM (Name cell is bold).`, async () => {
    const row = await listUoM.getRow({Name: uomCase});
    await listUoM.selectContextMenu(ListUnitsOfMeasureContextMenuItem.SetAsDefault, [row]); // Set Case as default

    await listUoM.verifyFirstRowDefaultUoM(uomCase);
  });

  it('Step 4 - Edit Case via context menu "Edit". Verify in dialog, Factor field = 1 and disabled for editing. Click Cancel to dismiss dialog.', async () => {
    const row = await listUoM.getRow({Name: uomCase}); // Edit UoM
    const [dlg] = await listUoM.selectContextMenu(ListUnitsOfMeasureContextMenuItem.Edit, [row]);
    await dlg.verifyDialogValues({Factor: '1'}); // Verify factor = 1 and disabled for edit
    await dlg.verifyDialogEnabled({Factor: 'false'});
    await dlg.clickCancel();
  });

  it(`Step 5 - Select ${uomMT} and ${uomCase} UoMs and verify "Edit" context menu is disabled (not supporting batch edit).`, async () => {
    const rows = await listUoM.selectListRows([{Name: uomMT}, {Name: uomCase}]); // Verify batch edit not supported
    await listUoM.verifyContextMenuDisabled(ListUnitsOfMeasureContextMenuItem.Edit, rows);
  });
});
